@@ -1,36 +1,14 @@
-import sys
-
 from .__version__ import *
+from .chains import *
 from .colors import *
 from .console import *
 from .converters import *
 from .decorators import *
+from .misc import *
 
 
 
 
-def get_size(obj, seen: set = set()):
-    """Recursively finds size of objects"""
-    size = sys.getsizeof(obj)
-    if seen is None: seen = set()
-
-    obj_id = id(obj)
-    if obj_id in seen:
-        return 0
-    # Important mark as seen *before* entering recursion to gracefully handle
-    # self-referential objects
-    seen.add(obj_id)
-    if isinstance(obj, dict):
-        size += sum([get_size(v, seen) for v in obj.values()])
-        size += sum([get_size(k, seen) for k in obj.keys()])
-    elif hasattr(obj, '__dict__'):
-        size += get_size(obj.__dict__, seen)
-    elif hasattr(obj, '__iter__') and not isinstance(obj, (str, bytes, bytearray)):
-        size += sum([get_size(i, seen) for i in obj])
-    return size
-
-
-
 __name__ = 'PythonDebugTools'
 __author__ = "Tyler Stegmaier"
 __email__ = "tyler.stegmaier.510@gmail.com"
